import type { SvgAttributes } from './transform.js';
import type { Config as SvgoConfig } from 'svgo';
import type { Compilation, Compiler, Module, NormalModule } from 'webpack';
export type SpriteType = 'global' | 'module' | 'entry' | 'raw' | 'inline';
export type SpriteTypeDetector = (resourcePath: string) => SpriteType | null;
export type SymbolIdParser = (resourcePath: string, rootPath: string) => string;
export interface SvgSymbol {
    resourcePath: string;
    symbolId: string;
    attributes: SvgAttributes;
}
export interface ContentfulSvgSymbol extends SvgSymbol {
    content: string;
}
export interface SvgSpritePluginOptions {
    defaultBehavior?: SpriteType;
    optimize?: boolean;
    symbolParser?: SymbolIdParser;
    typeDetector?: SpriteTypeDetector;
    outputFolder?: string;
}
type SpriteMap = Map<string, ContentfulSvgSymbol>;
export declare class SvgSpritePlugin {
    readonly pluginName = "webpack-svg-sprite-loader";
    readonly defaultBehavior: SpriteType;
    readonly optimize: boolean;
    readonly symbolParser: SymbolIdParser;
    readonly typeDetector: SpriteTypeDetector;
    checksums: Map<string, string>;
    sprites: Map<string, SpriteMap>;
    outputFolder: string;
    outputPath: string;
    publicPath: string;
    placeholder: string;
    placeholderChar: string;
    constructor(options?: SvgSpritePluginOptions);
    apply(compiler: Compiler): void;
    detectImportType(resourcePath: string): SpriteType;
    getSvgoOptions(): SvgoConfig;
    getSymbolId(resourcePath: string, rootPath: string): string;
    parseSvg(source: string): string;
    getSprite(spriteFilePath: string): SpriteMap;
    tapInCompilation(compiler: Compiler): void;
    tapInProcessAssets(compilation: Compilation): void;
    /** @FIXME: Sprites should be emitted as chunks and integrated into the
     * module graph instead. */
    emitSprites(compilation: Compilation): void;
    /** Materialize placeholder in a specific module. This only works because the
     * placeholder is the same length as the sprite path */
    replaceSpritePlaceholder(spritePath: string, resourcePath: string, compilation: Compilation): void;
    replaceSpritePlaceholders(spritePath: string, sprite: SpriteMap, compilation: Compilation): void;
    materializePlaceholders(compilation: Compilation): void;
    getResourceModule(resourcePath: string, compilation: Compilation): NormalModule;
    getResourceEntrypoint(resourcePath: string, compilation: Compilation): NormalModule;
    getGlobalSpritePath(): string;
    getSvgAbsPath(name: string): string;
    getSvgPublicPath(name: string): string;
    getEntrypointSpritePath(resourcePath: string, compilation: Compilation): string;
    getModuleIssuer(resourcePath: string, compilation: Compilation): Module | null;
    getModuleSpritePath(resourcePath: string, compilation: Compilation): string;
    getSpriteTarget(resourcePath: string, type: SpriteType, compilation: Compilation): string;
    getOrCreateSprite(spriteFilePath: string): SpriteMap;
    addSpriteSvg(spriteFilePath: string, icon: ContentfulSvgSymbol): void;
    serializeSvg(svg: ContentfulSvgSymbol): string;
    getSpriteContent(sprite: SpriteMap): string;
}
export {};
